@@ -1,7 +1,8 @@
 from .common import Entity
 from .repository import (
-    Repository, MemoryRepository, JsonRepository, SqlRepository)
+    Repository, MemoryRepository,
+    JsonRepository, SqlRepository, RestRepository)
 
 __author__ = 'Knowark'
 __email__ = 'info@knowark.com'
-__version__ = '0.3.0'
+__version__ = '0.3.1'
